Tools for MESSAGEix-GLOBIOM models
**********************************

.. image:: https://img.shields.io/pypi/v/message-ix-models.svg
   :alt: PyPI version
   :target: https://pypi.python.org/pypi/message-ix-models/

.. image:: https://readthedocs.com/projects/iiasa-energy-program-message-ix-models/badge/?version=latest
   :alt: Documentation status
   :target: https://docs.messageix.org/projects/models/en/latest/?badge=latest

.. image:: https://github.com/iiasa/message-ix-models/actions/workflows/pytest.yaml/badge.svg
   :alt: Test status
   :target: https://github.com/iiasa/message-ix-models/actions/workflows/pytest.yaml

.. image:: https://codecov.io/gh/iiasa/message-ix-models/branch/main/graph/badge.svg
   :alt: Test coverage
   :target: https://codecov.io/gh/iiasa/message-ix-models

``message_ix_models`` provides tools for research using the MESSAGEix-GLOBIOM family of models.
These models are built in the `MESSAGEix framework <https://docs.messageix.org>`_ and on the `ix modeling platform (ixmp) <https://docs.messageix.org/ixmp/>`_.

See the `online documentation <https://docs.messageix.org/projects/models/>`_ for further information.

License
=======

Copyright © 2020–2024 IIASA Energy, Climate, and Environment (ECE) program

Licensed under the Apache License, version 2.0.
